Ocean | Natural Earth
Description: Ocean polygon split into contiguous pieces. About Derives from 10m ocean coastlines. Ocean polygon is the same as Bathymetry 0 (sea level)

#

Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales
Search for:

- Home
- Features
- Downloads
- Blog
- Forums
- Corrections
- About

« 1:50m Physical Vectors « Downloads

## Ocean

Ocean polygon split into contiguous pieces.
Download ocean (450.91 KB) version 4.0.0

About

Derives from 10m ocean coastlines. Ocean polygon is the same as Bathymetry 0 (sea level).

(below) Yucatan peninsula, Cuba, and Hispaniola.

Issues

Caspian’s Garabogaz Aylagy and other “lagoons” might better belong in the lake theme than oceans.

Dependencies

This theme (and it’s inverse cousin, Land) are used to clip the raster imagery.

Version History

- 4.0.0
- 2.0.0
- 1.3.0
- 1.1.0
- 1.0.0

The master changelog is available on Github »